@@ -1,4 +1,5 @@
 from typing import List, Callable, Dict
+import numpy as np
 from tdw.add_ons.vr import VR
 from tdw.vr_data.rig_type import RigType
 from tdw.vr_data.oculus_touch_button import OculusTouchButton
@@ -41,6 +42,9 @@ class OculusTouch(VR):
         # Button press events.
         self._button_press_events_left: Dict[OculusTouchButton, Callable[[], None]] = dict()
         self._button_press_events_right: Dict[OculusTouchButton, Callable[[], None]] = dict()
+        # Axis events.
+        self._axis_events_left: List[Callable[[np.array], None]] = list()
+        self._axis_events_right: List[Callable[[np.array], None]] = list()
         # Non-graspable objects.
         if non_graspable is None:
             self._non_graspable: List[int] = list()
@@ -86,12 +90,12 @@ class OculusTouch(VR):
                     static_rigidbodies = StaticRigidbodies(resp[i])
                     for j in range(static_rigidbodies.get_num()):
                         object_id = static_rigidbodies.get_id(j)
-                        # Make all non-kinematic objects graspable unless they are in `self._non_graspable`.
-                        if object_id not in vr_node_ids and not static_rigidbodies.get_kinematic(j) and \
-                                object_id not in self._non_graspable:
-                            self.commands.append({"$type": "set_vr_graspable",
-                                                  "id": object_id})
-                            # Set "discrete" collision detection mode for each graspable object.
+                        if object_id not in vr_node_ids and not static_rigidbodies.get_kinematic(j):
+                            # Make all non-kinematic objects graspable unless they are in `self._non_graspable`.
+                            if object_id not in self._non_graspable:
+                                self.commands.append({"$type": "set_vr_graspable",
+                                                      "id": object_id})
+                            # Set "discrete" collision detection mode for all non-kinematic objects.
                             if self._discrete_collision_detection_mode:
                                 self.commands.append({"$type": "set_object_collision_detection_mode",
                                                       "id": object_id,
@@ -110,6 +114,11 @@ class OculusTouch(VR):
                         # Invoke the button press event.
                         if button in events:
                             events[button]()
+                # Invoke axis events.
+                for delta, axis in zip([oculus_touch_buttons.get_left_axis(), oculus_touch_buttons.get_right_axis()],
+                                       [self._axis_events_left, self._axis_events_right]):
+                    for event in axis:
+                        event(delta)
 
     def listen_to_button(self, button: OculusTouchButton, is_left: bool, function: Callable[[], None]) -> None:
         """
@@ -125,6 +134,19 @@ class OculusTouch(VR):
         else:
             self._button_press_events_right[button] = function
 
+    def listen_to_axis(self, is_left: bool, function: Callable[[np.array], None]) -> None:
+        """
+        Listen for Oculus Touch controller axis events.
+
+        :param is_left: If True, this is the left controller. If False, this is the right controller.
+        :param function: The function to invoke when the button is pressed. This function must a single argument (a numpy array of shape `(2)`, representing (x, y) coordinates) and return None.
+        """
+
+        if is_left:
+            self._axis_events_left.append(function)
+        else:
+            self._axis_events_right.append(function)
+
     def reset(self, non_graspable: List[int] = None) -> None:
         """
         Reset the VR rig. Call this whenever a scene is reset.
